"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdminPoliciesGuard = void 0;
const common_1 = require("@nestjs/common");
const core_1 = require("@nestjs/core");
const admin_policy_decorator_1 = require("./admin-policy.decorator");
const pbac_1 = require("@moonlightjs/pbac/pbac");
const admin_policy_service_1 = require("./admin-policy.service");
const common_2 = require("@moonlightjs/common");
const common_3 = require("@moonlightjs/common");
const constants_1 = require("../../../constants");
let AdminPoliciesGuard = class AdminPoliciesGuard {
    constructor(reflector, adminPolicyService) {
        this.reflector = reflector;
        this.adminPolicyService = adminPolicyService;
    }
    async canActivate(context) {
        const isIgnoreAuthorization = this.reflector.getAllAndOverride(common_3.IS_IGNORE_AUTHORIZATION, [context.getHandler(), context.getClass()]);
        if (isIgnoreAuthorization) {
            return true;
        }
        const evaluationParams = this.reflector.get(admin_policy_decorator_1.ADMIN_CHECK_POLICIES_KEY, context.getHandler()) || [];
        const request = context.switchToHttp().getRequest();
        const user = request.user;
        if (!user) {
            throw new common_2.HttpErrorException(constants_1.AdminUserErrorCodes.Unauthorized);
        }
        const policies = await this.adminPolicyService.getAllUserPolicies(user.sub);
        const pbac = new pbac_1.default(policies.map(fromAdminPolicyToPBACPolicy));
        const result = evaluationParams.every((evaluationParam) => {
            const requestParams = evaluationParam.getParamsFromRequest
                ? evaluationParam.getParamsFromRequest(request)
                : {};
            const buildParams = Object.assign({}, requestParams);
            return pbac.evaluate(Object.assign(Object.assign({}, evaluationParam), { context: {
                    user: user,
                    req: buildParams,
                } }));
        });
        if (!result) {
            throw new common_2.HttpErrorException(constants_1.AdminUserErrorCodes.PermissionDenied);
        }
        return true;
    }
};
AdminPoliciesGuard = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [core_1.Reflector,
        admin_policy_service_1.AdminPolicyService])
], AdminPoliciesGuard);
exports.AdminPoliciesGuard = AdminPoliciesGuard;
const fromAdminPolicyToPBACPolicy = (adminPolicy) => {
    const pbacPolicy = {
        Version: adminPolicy.version,
        Statement: adminPolicy.statements.map((statement) => {
            const a = {
                Sid: statement.Sid || undefined,
                Effect: statement.Effect,
                Action: statement.Action || undefined,
                NotAction: statement.NotAction || undefined,
                Resource: statement.Resource || undefined,
                NotResource: statement.NotResource || undefined,
                Principal: statement.Principal || undefined,
                NotPrincipal: statement.NotPrincipal || undefined,
                Condition: statement.Condition || undefined,
            };
            return (0, common_2.removeUndefinedProps)(a);
        }),
    };
    return pbacPolicy;
};
//# sourceMappingURL=admin-policy.guard.js.map