"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdminUserService = void 0;
const common_1 = require("@moonlightjs/common");
const common_2 = require("@nestjs/common");
const config_1 = require("@nestjs/config");
const constants_1 = require("../../constants");
const bcrypt = require("bcrypt");
const dto_1 = require("./dto");
let AdminUserService = class AdminUserService {
    constructor(prisma, configService) {
        this.prisma = prisma;
        this.configService = configService;
    }
    async getMe(id) {
        const adminUser = await this.prisma.adminUser.findFirst({
            where: {
                id,
            },
        });
        return (0, common_1.toDto)(dto_1.AdminUserProfileDto, adminUser);
    }
    async changePassword(id, input) {
        const user = await this.prisma.adminUser.findFirst({
            where: {
                id,
            },
        });
        if (!user) {
            throw new common_2.BadRequestException('User not found');
        }
        if (user.password) {
            if (!(await bcrypt.compare(input.currentPassword, user.password))) {
                throw new common_1.HttpErrorException(constants_1.AdminUserErrorCodes.PasswordInvalid);
            }
        }
        const salt = await bcrypt.genSalt();
        await this.prisma.adminUser.update({
            where: {
                id,
            },
            data: {
                updatedAt: new Date(),
                password: await bcrypt.hash(input.newPassword, salt),
            },
        });
    }
    async findOne(params) {
        const adminUser = await this.prisma.adminUser.findFirst(params);
        return (0, common_1.toDto)(dto_1.AdminUserDto, adminUser);
    }
    async findAll(params) {
        var _a, _b;
        params.skip = (_a = params.skip) !== null && _a !== void 0 ? _a : constants_1.DEFAULT_SKIP;
        params.take = (_b = params.take) !== null && _b !== void 0 ? _b : constants_1.DEFAULT_TAKE;
        const adminUsers = await this.prisma.adminUser.findMany(params);
        return adminUsers.map((adminUser) => (0, common_1.toDto)(dto_1.AdminUserDto, adminUser));
    }
    async findAllPagination(params) {
        var _a, _b;
        params.skip = (_a = params.skip) !== null && _a !== void 0 ? _a : constants_1.DEFAULT_SKIP;
        params.take = (_b = params.take) !== null && _b !== void 0 ? _b : constants_1.DEFAULT_TAKE;
        const [adminUsers, total] = await Promise.all([
            this.prisma.adminUser.findMany(params),
            this.prisma.adminUser.count({
                where: params.where,
            }),
        ]);
        return common_1.PagedResultDto.create({
            data: adminUsers.map((adminUser) => (0, common_1.toDto)(dto_1.AdminUserDto, adminUser)),
            pagination: common_1.Pagination.create({
                take: params.take,
                skip: params.skip,
                total: total,
            }),
        });
    }
    async create(params) {
        const adminUser = await this.prisma.adminUser.create(params);
        return (0, common_1.toDto)(dto_1.AdminUserDto, adminUser);
    }
    async update(params) {
        const adminUser = await this.prisma.adminUser.update(params);
        return (0, common_1.toDto)(dto_1.AdminUserDto, adminUser);
    }
    async remove(where) {
        const adminUser = await this.prisma.adminUser.delete({
            where,
        });
        return !!adminUser;
    }
    async resetPassword(id) {
        const defaultPassword = this.configService.get('DEFAULT_PASSWORD', '!moonlight@123');
        const salt = await bcrypt.genSalt();
        await this.prisma.adminUser.update({
            where: {
                id,
            },
            data: {
                updatedAt: new Date(),
                password: await bcrypt.hash(defaultPassword, salt),
            },
        });
    }
};
AdminUserService = __decorate([
    (0, common_2.Injectable)(),
    __metadata("design:paramtypes", [common_1.PrismaService,
        config_1.ConfigService])
], AdminUserService);
exports.AdminUserService = AdminUserService;
//# sourceMappingURL=admin-user.service.js.map